/*
Redner Odoo module
Copyright (C) 2016 XCG Consulting <https://xcg-consulting.fr>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

odoo.define("redner.report", function (require) {
    "use strict";

    var ActionManager = require("web.ActionManager");
    var core = require("web.core");
    var crash_manager = require("web.crash_manager");
    var framework = require("web.framework");
    var session = require("web.session");

    var _t = core._t;

    var trigger_download = function (session, response, c, action, options) {
        session.get_file({
            url: "/report/download",
            data: {data: JSON.stringify(response)},
            complete: framework.unblockUI,
            error: c.rpc_error.bind(c),
            success: function () {
                if (action && options && !action.dialog) {
                    options.on_close();
                }
            },
        });
    };

    ActionManager.include({
        ir_actions_report: function (action, options) {
            var self = this;

            // Redner reports
            if ("report_type" in action && action.report_type == "redner") {
                framework.blockUI();
                action = _.clone(action);
                _t = core._t;
                var report_url = "/report/redner/" + action.report_name;
                // generic report: no query string
                // particular: query string of action.data.form and context
                if (!("data" in action) || !action.data) {
                    if ("active_ids" in action.context) {
                        report_url += "/" + action.context.active_ids.join(",");
                    }
                } else {
                    report_url +=
                        "?&options=" + encodeURIComponent(JSON.stringify(action.data));
                    report_url +=
                        "&context=" +
                        encodeURIComponent(JSON.stringify(action.context));
                }

                var response = new Array();
                response[0] = report_url;
                response[1] = action.report_type;
                var c = crash_manager;
                return trigger_download(
                    self.getSession(),
                    response,
                    c,
                    action,
                    options
                );
            } else {
                return self._super(action, options);
            }
        },
    });
});
